# Specification Documents, IEEE and SISO
# Distributed Interactive Simulation (DIS) Protocol

<!-- To properly view Markdown, go the the online web page:
     https://gitlab.nps.edu/Savage/NetworkedGraphicsMV3500/-/blob/master/specifications/README.md -->

*Distributed Interactive Simulation (DIS) is an 
[Institute of Electrical and Electronics Engineers (IEEE)](https://www.ieee.org) standard for conducting 
real-time platform-level wargaming across multiple host computers and is used worldwide,
especially by military organizations but also by other agencies such as those involved in
space exploration and medicine.*
* Wikipedia: [Distributed Interactive Simulation (DIS)](https://en.wikipedia.org/wiki/Distributed_Interactive_Simulation) IEEE Standard and [RPR FOM](https://en.wikipedia.org/wiki/RPR_FOM)
* [Simulation Interoperability Standards Organization (SISO)](https://www.sisostandards.org): "Simulation Interoperability and Reuse through Standards"
* SISO [DIS / RPR FOM PSG - Distributed Interactive Simulation / Real-time Platform Reference Federation Object Model](https://www.sisostandards.org/StandardsActivities/SupportGroups/DISRPRFOMPSG.aspx) Product Support Group (PSG)
* SISO [Standards Data Files](https://www.sisostandards.org/Schemas.aspx) including various schemas

## Working-Group Resources

### C2SIM PSG/PDG - Command and Control Systems - Simulationation Systems Interoperability (C2SIM)
* [Library](https://sisostandards.connectedcommunity.org/communities/community-home/librarydocuments?communitykey=e127ad67-6994-466f-808b-e7a1719c2478&LibraryFolderKey=&DefaultView=)


### DIS/RPR FOM Product Support Group <a href="https://www.sisostandards.org/StandardsActivities/SupportGroups/DISRPRFOMPSG.aspx" target="_blank"><img src="SisoLogo.jpg" width="314" align="right"/></a>
* "The Distributed Interactive Simulation / Real-time Platform Reference Federation Object Model (DIS / RPR FOM) Product Support Group (PSG) is a permanent support group chartered by the SISO Standards Activity Committee to support multiple DIS-related products."
* [Distributed Interactive Simulation / Real-time Platform Reference Federation Object Model (DIS / RPR FOM) Product Support Group (PSG)](https://www.sisostandards.org/StandardsActivities/SupportGroups/DISRPRFOMPSG.aspx)
* [SISO Digital Library](https://www.sisostandards.org/Default.aspx?tabid=105&EntryId=31596)
** [DIS Introduction and Briefings](https://www.sisostandards.org/Default.aspx?tabid=105&EntryId=31596)
** [IEEE 1278 Bibliography Material](https://www.sisostandards.org/Default.aspx?tabid=105&EntryId=31596)
** [DIS PDU data structures](IeeeDisPduColorFigures.pdf)
** [Compressed DIS](2019-SIW-Presentation-039_CompressedDis.pdf) overview, Lance Call, Simulation Interoperability Workshop (SIW), Orlando Florida, February 2019.
** DISv8 Library](https://sisostandards.connectedcommunity.org/communities/community-home/librarydocuments?communitykey=f63434dd-df8c-4b41-892c-f03f0a2ea4bb&LibraryFolderKey=&DefaultView=)
Specification download links follow.  For free access, IEEE standards must be downloaded manually while within NPS campus or firewall.

## Standards Documents

An IEEEExplore account is usually required to access or purchase these standards documents. Meanwhile, 
NPS personnel can obtain the following standards without charge when accessing via nps.edu networks.

### 1278.1-2012. IEEE Standard for Distributed Interactive Simulation (DIS) - Application Protocols <a href="https://ieeexplore.ieee.org/document/6387564" target="_blank"><img src="IeeeLogo.jpg" width="120" align="right"/></a>
* https://ieeexplore.ieee.org/document/6387564
* *Abstract.* 
Data messages, known as Protocol Data Units (PDUs), that are exchanged on a network among simulation applications are defined. These PDUs are for interactions that take place within specified domains called protocol families, which include Entity Information/ Interaction, Warfare, Logistics, Simulation Management, Distributed Emission Regeneration, Radio Communications, Entity Management, Minefield, Synthetic Environment, Simulation Management with Reliability, Information Operations, Live Entity Information/Interaction, and Non-Real-Time protocol.
* Date of Publication: 19 Dec. 2012
* Electronic ISBN: 978-0-7381-7310-8
* Also [IEEE Std 1278.1-2012 (Revision of IEEE Std 1278.1-1995)](https://standards.ieee.org/findstds/standard/1278.1-2012.html)

---

### 1278.2-2015. IEEE Standard for Distributed Interactive Simulation (DIS) - Communication Services and Profiles <a href="https://ieeexplore.ieee.org/document/7459689" target="_blank"><img src="IeeeLogo.jpg" width="120" align="right"/></a>
* https://ieeexplore.ieee.org/document/7459689
* *Abstract.* 
Communication services to support information exchange between simulation applications participating in the distributed interactive simulation (DIS) environment are defined. These communication services describe a connectionless information transfer that supports real-time, as well as non-real-time, exchange. Several communication profiles specifying communication services are provided.
* *Scope.*
This standard establishes the requirements for the communication services to be used in a DIS simulation. This standard supports IEEE Std 1278.1.
* *Purpose.*
The purpose of this standard is to establish requirements for communication subsystems that support DIS applications. This standard provides service requirements and associated profiles that can be individually selected to meet specific DIS system operational requirements.
* Date of Publication: 6 Nov. 2015
* Electronic ISBN: 978-0-7381-9909-2 

---

### 1278.3-1996. IEEE Recommended Practice for Distributed Interactive Simulation - Exercise Management and Feedback <a href="https://ieeexplore.ieee.org/document/587529" target="_blank"><img src="IeeeLogo.jpg" width="120" align="right"/></a>
* https://ieeexplore.ieee.org/document/587529
* *Abstract.* 
Guidelines are established for exercise management and feedback in distributed interactive simulation (DIS) exercises. Guidance is provided to sponsors, providers and supporters of DIS-compliant systems and exercises as well as to developers of DIS exercise management and feedback stations. The activities of the organizations involved in a DIS exercise and the top-level processes used to accomplish those activities are addressed. The functional requirements of the exercise management and feedback process are also addressed. This standard is one of a series of standards developed for DIS to assure interoperability between dissimilar simulations for currently installed and future simulations developed by different organizations.
* Date of Publication 1997, Reaffirmed 2002.

---

### 4. 1278.4-1997. IEEE Recommended Practice for Distributed Interactive Simulation - Verification, Validation, and Accreditation <a href="https://ieeexplore.ieee.org/document/8685803" target="_blank"><img src="IeeeLogo.jpg" width="120" align="right"/></a>
* https://ieeexplore.ieee.org/document/8685803
* *Abstract.* 
Guidelines are established for the verification, validation, and accreditation (VV&A) of distributed interactive simulation (DIS) exercises. How-to procedures for planning and conducting DIS exercise VV&A are provided. Intended for use in conjunction with IEEE Std 1278.3-1996, this recommended practice presents data flow and connectivity for all proposed verification and validation activities and provides rationale and justification for each step. VV&A guidance is provided to exercise users/sponsors and developers.
* Date of Publication: 10 Sept. 2013
* Electronic ISBN: 978-0-7381-6281-2

---

### 5. SISO-REF-010: Reference for Enumerations for Simulation Interoperability <a href="https://www.sisostandards.org/page/ReferenceDocuments" target="_blank"><img src="SisoLogo.jpg" width="314" align="right"/></a>
* https://www.sisostandards.org/page/ReferenceDocuments (scroll down to bottom of page)
* *Abstract.* 
SISO-REF-010 specifies numerical values and associated definitions for fields that are identified as enumerations in SISO Standards Products and SISO-sponsored standards published by IEEE for High Level Architecture (HLA) and Distributed Interactive Simulation (DIS). Enumerations for simulations may be applied in other architectures, such as the Test and Training Enabling Architecture (TENA).
* Resources include [SISO-REF-010 distribution](https://www.sisostandards.org/DigitalLibrary.aspx?Command=Core_Download&EntryId=46171),
[enumerations PDF](https://www.sisostandards.org/DigitalLibrary.aspx?Command=Core_Download&EntryId=46172),
[Operations Manual (OPMAN)](https://www.sisostandards.org/DigitalLibrary.aspx?Command=Core_Download&EntryId=47284) and
[latest version of all resources](https://svn.code.sf.net/p/esitools/code/Release_Information/Current_DRAFT)
---

### 6. SISO-STD-001-2015: Standard for Guidance, Rationale, and Interoperability Modalities (GRIM) for the Real-time Platform Reference Federation Object Model (RPR FOM) <a href="https://www.sisostandards.org/page/ReferenceDocuments" target="_blank"><img src="SisoLogo.jpg" width="314" align="right"/></a>
* https://www.sisostandards.org/ProductsPublications/Standards/SISOStandards.aspx (scroll down near bottom of page)
* *Abstract.* 
SISO-STD-001-2015 encapsulates guidance in the use of the RPR FOM. It provides descriptions of FOM classes and data types and the relationship between Distributed Interactive Simulation (DIS) and the High Level Architecture (HLA)-based RPR FOM, as well as rules for accomplishing specific distributed simulation tasks.
* Version 2.0 (10 Aug 2015)

---
